@@ -17,7 +17,8 @@ try:
     from nb2workflow import logstash
     logstasher = logstash.LogStasher()
 except Exception as e:
-    logging.debug("unable to setup logstash",repr(e))
+    import logging
+    logging.warning("unable to setup logstash",repr(e))
 
     logstasher = None
 
@@ -27,7 +28,8 @@ try:
 except ImportError:
     sentry_sdk = None
 except Exception as e:
-    logging.debug("big problem with sentry:",repr(e))
+    import logging
+    logging.warning("big problem with sentry:",repr(e))
     sentry_sdk = None
 
 
